@@ -1,6 +1,6 @@
 from settings import settings
 
-from office365.runtime.auth.clientCredential import ClientCredential
+from office365.runtime.auth.client_credential import ClientCredential
 from office365.sharepoint.client_context import ClientContext
 
 
@@ -13,7 +13,7 @@ ctx = ClientContext.connect_with_credentials(settings['url'],
                                              ClientCredential(settings['client_credentials']['client_id'],
                                                               settings['client_credentials']['client_secret']))
 
-ctx.get_pending_request().beforeExecute += set_proxy
+ctx.pending_request().beforeExecute += set_proxy
 
 target_web = ctx.web
 ctx.load(target_web)
