@@ -4,7 +4,7 @@ import tempfile
 
 from settings import settings
 
-from office365.runtime.auth.clientCredential import ClientCredential
+from office365.runtime.auth.client_credential import ClientCredential
 from office365.sharepoint.client_context import ClientContext
 
 "Demonstrates how to export a List data"
