@@ -1,5 +1,5 @@
-from office365.runtime.client_value_object import ClientValueObject
+from office365.runtime.client_value import ClientValue
 
 
-class ItemReference(ClientValueObject):
+class ItemReference(ClientValue):
     """The ItemReference resource provides information necessary to address a DriveItem via the API."""
