@@ -1,6 +1,6 @@
 from office365.onedrive.list import List
 from office365.runtime.client_object_collection import ClientObjectCollection
-from office365.runtime.client_query import CreateEntityQuery
+from office365.runtime.queries.create_entity_query import CreateEntityQuery
 
 
 class ListCollection(ClientObjectCollection):
