@@ -1,4 +1,6 @@
-from office365.runtime.client_value_object import ClientValueObject
+import copy
+
+from office365.runtime.client_value import ClientValue
 from office365.runtime.odata.odata_query_options import QueryOptions
 
 
@@ -6,7 +8,7 @@ class ClientObject(object):
 
     def __init__(self, context, resource_path=None, properties=None, parent_collection=None):
         """
-        Base client object
+        Base client object which define named properties and relationships of an entity
 
         :type parent_collection: office365.runtime.client_object_collection.ClientObjectCollection or None
         :type properties: dict or None
@@ -14,7 +16,7 @@ class ClientObject(object):
         :type context: office365.runtime.client_runtime_context.ClientRuntimeContext
         """
         self._properties = {}
-        self._changes = []
+        self._changed_properties = []
         self._entity_type_name = None
         self._query_options = QueryOptions()
         self._parent_collection = parent_collection
@@ -24,13 +26,35 @@ class ClientObject(object):
             for k, v in properties.items():
                 self.set_property(k, v, True)
 
+    def execute_query(self):
+        self.context.execute_query()
+        return self
+
+    def execute_query_retry(self):
+        self.context.execute_query_retry()
+        return self
+
+    def build_request(self):
+        return self.context.build_request()
+
+    def get(self):
+        self.context.load(self)
+        return self
+
     def is_property_available(self, name):
-        """Returns a Boolean value that indicates whether the specified property has been retrieved or set."""
+        """Returns a Boolean value that indicates whether the specified property has been retrieved or set.
+
+        :param str name: A Property name
+        """
         if name in self.properties:
             return True
         return False
 
     def expand(self, names):
+        """
+
+        :type names: list[str]
+        """
         self.query_options.expand = names
         return self
 
@@ -43,15 +67,25 @@ class ClientObject(object):
             return
         self._parent_collection.remove_child(self)
 
+    def get_property(self, name):
+        getter_name = name[0].lower() + name[1:]
+        if hasattr(self, getter_name):
+            return getattr(self, getter_name)
+        return self._properties.get(name, None)
+
     def set_property(self, name, value, persist_changes=True):
-        """Set resource property value"""
+        """Sets Property value
+        :param str name: Property name
+        :param any value: Property value
+        :param bool persist_changes: Persist changes
+        """
         if persist_changes:
-            self._changes.append(name)
+            self._changed_properties.append(name)
 
         safe_name = name[0].lower() + name[1:]
-        if hasattr(self, safe_name):
+        if hasattr(self, safe_name) and value is not None:
             prop_type = getattr(self, safe_name)
-            if isinstance(prop_type, ClientObject) or isinstance(prop_type, ClientValueObject):
+            if isinstance(prop_type, ClientObject) or isinstance(prop_type, ClientValue):
                 [prop_type.set_property(k, v, persist_changes) for k, v in value.items()]
                 self._properties[name] = prop_type
             else:
@@ -60,20 +94,41 @@ class ClientObject(object):
             self._properties[name] = value
 
     def to_json(self):
-        return dict((k, v) for k, v in self.properties.items() if k in self._changes)
+        return dict((k, v) for k, v in self.properties.items() if k in self._changed_properties)
 
     def ensure_property(self, name, action):
         """
-        Ensures property is loaded
+        Ensures if property is loaded
 
-        :type action: any
+        :type action: () -> None
         :type name: str
         """
-        if not self.is_property_available(name):
-            self.context.load(self, [name])
-            self.context.afterExecuteOnce += action
+        names_to_include = [name]
+        self.ensure_properties(names_to_include, action)
+        return self
+
+    def ensure_properties(self, names, action):
+        """
+        Ensure if list of properties are loaded
+
+        :type action: () -> None
+        :type names: str or list[str]
+        """
+        names_to_include = [n for n in names if not self.is_property_available(n)]
+        if len(names_to_include) > 0:
+            qry = self.context.load(self, names_to_include)
+            if callable(action):
+                def _process_query(current_query):
+                    if current_query.id == qry.id:
+                        action()
+                self.context.after_execute_query(_process_query)
         else:
-            action(self)
+            action()
+
+    def clone_object(self):
+        result = copy.deepcopy(self)
+        result._context = self.context
+        return result
 
     @property
     def entity_type_name(self):
@@ -81,15 +136,14 @@ class ClientObject(object):
             self._entity_type_name = "SP." + type(self).__name__
         return self._entity_type_name
 
-    @entity_type_name.setter
-    def entity_type_name(self, value):
-        self._entity_type_name = value
-
     @property
     def resource_url(self):
-        """Generate resource Url"""
+        """Generate resource Url
+
+        :rtype: str or None
+        """
         if self.resource_path:
-            url = self.context.service_root_url + self.resource_path.to_url()
+            url = self.context.service_root_url() + self.resource_path.to_url()
             if not self.query_options.is_empty:
                 url = url + "?" + self._query_options.to_url()
             return url
