@@ -1,10 +1,10 @@
 from office365.runtime.client_object import ClientObject
-from office365.runtime.client_query import UpdateEntityQuery
+from office365.runtime.queries.update_entity_query import UpdateEntityQuery
 
 
 class BaseEntity(ClientObject):
 
-    def __init__(self, context, resource_path=None, namespace="SP"):
+    def __init__(self, context, resource_path=None, namespace="SP", parent_collection=None):
         """
         SharePoint base entity
 
@@ -12,25 +12,18 @@ class BaseEntity(ClientObject):
         :param ResourcePath resource_path:
         :param str namespace:
         """
-        super().__init__(context, resource_path)
+        super().__init__(context, resource_path, None, parent_collection)
         self._namespace = namespace
 
     def with_credentials(self, credentials):
         self.context.with_credentials(credentials)
         return self
 
-    def execute_query(self):
-        self.context.execute_query()
-        return self
-
-    def load(self):
-        self.context.load(self)
-        return self
-
     def update(self):
         """Updates the resource."""
         qry = UpdateEntityQuery(self)
         self.context.add_query(qry)
+        return self
 
     @property
     def context(self):
