@@ -1,4 +1,4 @@
-from office365.runtime.clientValue import ClientValue
+from office365.runtime.client_value import ClientValue
 
 
 class SPSiteCreationRequest(ClientValue):
