@@ -3,8 +3,10 @@ from office365.runtime.client_result import ClientResult
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
 from office365.runtime.resource_path import ResourcePath
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
+from office365.sharepoint.changes.change_collection import ChangeCollection
 from office365.sharepoint.lists.list import List
 from office365.sharepoint.principal.user import User
+from office365.sharepoint.recyclebin.recycleBinItemCollection import RecycleBinItemCollection
 from office365.sharepoint.webs.web import Web
 
 
@@ -14,6 +16,27 @@ class Site(ClientObject):
     def __init__(self, context):
         super(Site, self).__init__(context, ResourcePath("Site", None))
 
+    def get_changes(self, query):
+        """Returns the collection of all changes from the change log that have occurred within the scope of the site,
+        based on the specified query.
+
+        :param office365.sharepoint.changes.change_query.ChangeQuery query: Specifies which changes to return
+        """
+        changes = ChangeCollection(self.context)
+        qry = ServiceOperationQuery(self, "getChanges", None, query, "query", changes)
+        self.context.add_query(qry)
+        return changes
+
+    def get_recycle_bin_items(self, pagingInfo=None, rowLimit=100, isAscending=True, orderBy=None, itemState=None):
+        result = RecycleBinItemCollection(self.context)
+        payload = {
+            "rowLimit": rowLimit,
+            "isAscending": isAscending
+        }
+        qry = ServiceOperationQuery(self, "GetRecycleBinItems", None, payload, None, result)
+        self.context.add_query(qry)
+        return result
+
     @staticmethod
     def get_url_by_id(context, site_id, stop_redirect=False):
         """Gets Site Url By Id
@@ -67,3 +90,10 @@ class Site(ClientObject):
             return self.properties['owner']
         else:
             return User(self.context, ResourcePath("owner", self.resource_path))
+
+    @property
+    def recycleBin(self):
+        """Get recycle bin"""
+        return self.properties.get('RecycleBin',
+                                   RecycleBinItemCollection(self.context,
+                                                            ResourcePath("RecycleBin", self.resource_path)))
