@@ -1,5 +1,5 @@
+from office365.runtime.queries.service_operation_query import ServiceOperationQuery
 from office365.runtime.resource_path import ResourcePath
-from office365.runtime.queries.serviceOperationQuery import ServiceOperationQuery
 from office365.sharepoint.base_entity import BaseEntity
 from office365.sharepoint.tenant.administration.siteProperties import SiteProperties
 from office365.sharepoint.tenant.administration.sitePropertiesCollection import SitePropertiesCollection
@@ -16,7 +16,8 @@ class Tenant(BaseEntity):
     def create_site(self, site_create_props):
         """Queues a site collection for creation with the specified properties.
 
-        :param SiteCreationProperties site_create_props: A SiteCreationProperties object that contains the initial properties
+        :param SiteCreationProperties site_create_props:
+        A SiteCreationProperties object that contains the initial properties
         of the new site collection.
         """
         result = SpoOperation(self.context)
