@@ -1,4 +1,4 @@
-from office365.runtime.client_query import DeleteEntityQuery
+from office365.runtime.queries.delete_entity_query import DeleteEntityQuery
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
 from office365.runtime.resource_path import ResourcePath
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
@@ -35,6 +35,7 @@ class View(BaseEntity):
         qry = DeleteEntityQuery(self)
         self.context.add_query(qry)
         self.remove_from_parent_collection()
+        return self
 
     @property
     def contentTypeId(self):
@@ -100,3 +101,4 @@ class View(BaseEntity):
             elif name == "Title":
                 self._resource_path = ResourcePathServiceOperation(
                     "GetByTitle", [value], self._parent_collection.resource_path)
+        return self
