@@ -1,28 +1,38 @@
-from office365.runtime.client_query import UpdateEntityQuery, DeleteEntityQuery, ClientQuery
 from office365.runtime.client_result import ClientResult
+from office365.runtime.client_value_collection import ClientValueCollection
+from office365.runtime.queries.client_query import ClientQuery
+from office365.runtime.queries.delete_entity_query import DeleteEntityQuery
+from office365.runtime.queries.service_operation_query import ServiceOperationQuery
+from office365.runtime.queries.update_entity_query import UpdateEntityQuery
 from office365.runtime.resource_path import ResourcePath
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
-from office365.runtime.queries.serviceOperationQuery import ServiceOperationQuery
 from office365.sharepoint.actions.getWebUrlFromPage import GetWebUrlFromPageUrlQuery
-from office365.sharepoint.permissions.roleDefinitionCollection import RoleDefinitionCollection
-from office365.sharepoint.sharing.externalSharingSiteOption import ExternalSharingSiteOption
-from office365.sharepoint.sharing.objectSharingSettings import ObjectSharingSettings
-from office365.sharepoint.sharing.sharingResult import SharingResult
-from office365.sharepoint.webs.regionalSettings import RegionalSettings
-from office365.sharepoint.permissions.basePermissions import BasePermissions
-from office365.sharepoint.changes.changeCollection import ChangeCollection
+from office365.sharepoint.changes.change_collection import ChangeCollection
 from office365.sharepoint.contenttypes.content_type_collection import ContentTypeCollection
 from office365.sharepoint.fields.field_collection import FieldCollection
 from office365.sharepoint.files.file import File
 from office365.sharepoint.folders.folder import Folder
 from office365.sharepoint.folders.folder_collection import FolderCollection
-from office365.sharepoint.principal.group import Group
-from office365.sharepoint.principal.group_collection import GroupCollection
+from office365.sharepoint.listitems.listitem import ListItem
+from office365.sharepoint.lists.documentLibraryInformation import DocumentLibraryInformation
 from office365.sharepoint.lists.list import List
 from office365.sharepoint.lists.list_collection import ListCollection
+from office365.sharepoint.permissions.basePermissions import BasePermissions
+from office365.sharepoint.permissions.roleDefinitionCollection import RoleDefinitionCollection
 from office365.sharepoint.permissions.securable_object import SecurableObject
+from office365.sharepoint.principal.group import Group
+from office365.sharepoint.principal.group_collection import GroupCollection
 from office365.sharepoint.principal.user import User
 from office365.sharepoint.principal.user_collection import UserCollection
+from office365.sharepoint.recyclebin.recycleBinItemCollection import RecycleBinItemCollection
+from office365.sharepoint.sharing.externalSharingSiteOption import ExternalSharingSiteOption
+from office365.sharepoint.sharing.objectSharingSettings import ObjectSharingSettings
+from office365.sharepoint.sharing.sharingResult import SharingResult
+from office365.sharepoint.ui.applicationpages.clientPeoplePickerQueryParameters import ClientPeoplePickerQueryParameters
+from office365.sharepoint.ui.applicationpages.clientPeoplePickerWebServiceInterface import (
+    ClientPeoplePickerWebServiceInterface,
+)
+from office365.sharepoint.webs.regional_settings import RegionalSettings
 
 
 class Web(SecurableObject):
@@ -43,6 +53,7 @@ class Web(SecurableObject):
     @staticmethod
     def get_web_url_from_page_url(context, page_full_url):
         """Determine whether site exists
+
         :type context: office365.sharepoint.client_context.ClientContext
         :type page_full_url: str
         """
@@ -53,7 +64,9 @@ class Web(SecurableObject):
     def get_sub_webs_filtered_for_current_user(self, query):
         """Returns a collection of objects that contain metadata about subsites of the current site (2) in which the
         current user is a member.
-        :type query: SubwebQuery"""
+
+        :type query: office365.sharepoint.webs.subweb_query.SubwebQuery
+        """
         users = UserCollection(self.context)
         qry = ServiceOperationQuery(self, "getSubwebsFilteredForCurrentUser", {
             "nWebTemplateFilter": query.WebTemplateFilter,
@@ -62,16 +75,34 @@ class Web(SecurableObject):
         self.context.add_query(qry)
         return users
 
+    def get_recycle_bin_items(self, pagingInfo=None, rowLimit=100, isAscending=True, orderBy=None, itemState=None):
+        """
+
+        :param str pagingInfo:
+        :param int rowLimit:
+        :param bool isAscending:
+        :param orderBy: int
+        :param int itemState:
+        """
+        result = RecycleBinItemCollection(self.context)
+        payload = {
+            "rowLimit": rowLimit,
+            "isAscending": isAscending
+        }
+        qry = ServiceOperationQuery(self, "GetRecycleBinItems", None, payload, None, result)
+        self.context.add_query(qry)
+        return result
+
     def get_all_webs(self):
         """Returns a collection containing a flat list of all Web objects in the Web object."""
         result = ClientResult(self.webs)
-        qry = ClientQuery(self.webs, None, None, result)
+        qry = ClientQuery(self.context, self.webs, None, None, result)
         self.context.add_query(qry)
-        self.context.afterExecuteOnce += self._load_sub_webs
-        return result
 
-    def _load_sub_webs(self, result):
-        self._load_sub_webs_inner(result.value)
+        def _load_sub_webs(resp):
+            self._load_sub_webs_inner(result.value)
+        self.context.after_execute(_load_sub_webs)
+        return result
 
     def _load_sub_webs_inner(self, webs, result=None):
         if result is None:
@@ -88,12 +119,14 @@ class Web(SecurableObject):
         """Update a Web resource"""
         qry = UpdateEntityQuery(self)
         self.context.add_query(qry)
+        return self
 
     def delete_object(self):
         """Delete a Web resource"""
         qry = DeleteEntityQuery(self)
         self.context.add_query(qry)
         self.remove_from_parent_collection()
+        return self
 
     @staticmethod
     def create_anonymous_link(context, url, is_edit_link):
@@ -124,7 +157,8 @@ class Web(SecurableObject):
               The two possible URL formats are:
               1) The URL of the site, with the path of the object in SharePoint represented as query string parameters,
               forSharing set to 1 if sharing, and mbypass set to 1 to bypass any mobile logic
-              e.g. http://contoso.com/?forSharing=1&mbypass=1&List=%7BCF908473%2D72D4%2D449D%2D8A53%2D4BD01EC54B84%7D&obj={CF908473-72D4-449D-8A53-4BD01EC54B84},1,DOCUMENT
+              e.g. http://contoso.com/?forSharing=1&mbypass=1&List=%7BCF908473%2D72D4%2D449D%2D8A53%2D4BD01EC54B84%7D&
+              obj={CF908473-72D4-449D-8A53-4BD01EC54B84},1,DOCUMENT
               2) The URL of the SharePoint object (web, list, item) intended for sharing
               e.g. http://contoso.com/Documents/SampleFile.docx
         :param int group_id: The id value of the permissions group if adding to a group, 0 otherwise.
@@ -182,6 +216,7 @@ class Web(SecurableObject):
 
     def does_user_have_permissions(self, permission_mask):
         """Returns whether the current user has the given set of permissions.
+
         :type permission_mask: BasePermissions
         """
         result = ClientResult(bool)
@@ -210,10 +245,11 @@ class Web(SecurableObject):
     def default_document_library(self):
         """Retrieves the default document library."""
         return List(self.context,
-                    ResourcePathServiceOperation("defaultDocumentLibrary", [], self.resource_path))
+                    ResourcePathServiceOperation("defaultDocumentLibrary", None, self.resource_path))
 
     def get_list(self, url):
         """Get list by url
+
         :type url: str
         """
         return List(self.context,
@@ -223,16 +259,104 @@ class Web(SecurableObject):
         """Returns the collection of all changes from the change log that have occurred within the scope of the site,
         based on the specified query.
 
-        :param office365.sharepoint.changeQuery.ChangeQuery query: Specifies which changes to return
+        :param office365.sharepoint.changes.change_query.ChangeQuery query: Specifies which changes to return
         """
         changes = ChangeCollection(self.context)
         qry = ServiceOperationQuery(self, "getChanges", None, query, "query", changes)
         self.context.add_query(qry)
         return changes
 
+    def share(self, user_principal_name,
+              shareOption=ExternalSharingSiteOption.View,
+              sendEmail=True, emailSubject=None, emailBody=None):
+        """
+        Share a Web with user
+
+        :param str user_principal_name: User identifier
+        :param ExternalSharingSiteOption shareOption: The sharing type of permission to grant on the object.
+        :param bool sendEmail: A flag to determine if an email notification SHOULD be sent (if email is configured).
+        :param str emailSubject: The email subject.
+        :param str emailBody: The email subject.
+        :return: SharingResult
+        """
+
+        picker_result = ClientResult(str)
+        sharing_result = ClientResult(SharingResult(self.context))
+
+        def _picker_value_resolved(picker_value):
+            picker_result.value = picker_value
+
+        def _grp_resolved(role_value):
+            def _web_loaded():
+                sharing_result.value = Web.share_object(self.context, self.url, picker_result.value, role_value,
+                                                        0,
+                                                        False, sendEmail, False, emailSubject, emailBody)
+
+            self.ensure_property("Url", _web_loaded)
+
+        params = ClientPeoplePickerQueryParameters(user_principal_name)
+        ClientPeoplePickerWebServiceInterface.client_people_picker_resolve_user(self.context, params,
+                                                                                _picker_value_resolved)
+        Web._resolve_group_value(self.context, shareOption, _grp_resolved)
+        return sharing_result.value
+
+    def unshare(self):
+        """
+        Unshare a Web
+
+        :return: SharingResult
+        """
+        sharing_result = ClientResult(SharingResult(self.context))
+
+        def _web_initialized():
+            sharing_result.value = Web.unshare_object(self.context, self.url)
+        self.ensure_property("Url", _web_initialized)
+        return sharing_result.value
+
+    @staticmethod
+    def get_document_libraries(context, web_full_url):
+        """
+        Returns the document libraries of a SharePoint site, specifically a list of objects that represents
+        document library information. Document libraries that are private—picture library, catalog library,
+        asset library, application list, form template or libraries—for whom the user does not have permission to view
+        the items are not included.
+
+        :param office365.sharepoint.client_context.ClientContext context: SharePoint context
+        :param str web_full_url: The URL of the web.
+        """
+        result = ClientValueCollection(DocumentLibraryInformation())
+        payload = {
+            "webFullUrl": web_full_url
+        }
+        qry = ServiceOperationQuery(context.web, "GetDocumentLibraries", None, payload, None, result)
+        qry.static = True
+        context.add_query(qry)
+        return result
+
+    @staticmethod
+    def _resolve_group_value(context, share_option, on_resolved):
+        """
+
+        :param office365.sharepoint.client_context.ClientContext context:
+        :param ExternalSharingSiteOption share_option:
+        :param (str) -> None on_resolved:
+        """
+        options = {
+            ExternalSharingSiteOption.View: context.web.associatedVisitorGroup,
+            ExternalSharingSiteOption.Edit: context.web.associatedMemberGroup,
+            ExternalSharingSiteOption.Owner: context.web.associatedOwnerGroup,
+        }
+        grp = options[share_option]
+        context.load(grp)
+
+        def _group_resolved(resp):
+            role_value = "group:{groupId}".format(groupId=grp.properties["Id"])
+            on_resolved(role_value)
+        context.after_execute(_group_resolved)
+
     @staticmethod
     def share_object(context, url, peoplePickerInput,
-                     roleValue=ExternalSharingSiteOption.View,
+                     roleValue=None,
                      groupId=0, propagateAcl=False,
                      sendEmail=True, includeAnonymousLinkInEmail=False, emailSubject=None, emailBody=None,
                      useSimplifiedRoles=True):
@@ -241,11 +365,11 @@ class Web(SecurableObject):
         which contains the completion script and a page to redirect to if desired.
 
 
-        :param office365.sharepoint.client_context.ClientContext context:
+        :param office365.sharepoint.client_context.ClientContext context: SharePoint context
         :param str url: The URL of the website with the path of an object in SharePoint query string parameters.
         :param str roleValue: The sharing role value for the type of permission to grant on the object.
         :param str peoplePickerInput: A string of JSON representing users in people picker format.
-        :param str groupId: The ID of the group to be added. Zero if not adding to a permissions group.
+        :param int groupId: The ID of the group to be added. Zero if not adding to a permissions group.
         :param bool propagateAcl:  A flag to determine if permissions SHOULD be pushed to items with unique permissions.
         :param bool sendEmail: A flag to determine if an email notification SHOULD be sent (if email is configured).
         :param bool includeAnonymousLinkInEmail: If an email is being sent, this determines if an anonymous link
@@ -274,13 +398,59 @@ class Web(SecurableObject):
         context.add_query(qry)
         return result
 
+    @staticmethod
+    def unshare_object(context, url):
+        """
+        Removes Sharing permissions on an object.
+
+        :param office365.sharepoint.client_context.ClientContext context: SharePoint context
+        :param str url: A SharingResult object which contains status codes pertaining to the completion of the operation
+        :return: SharingResult
+        """
+        result = SharingResult(context)
+        payload = {
+            "url": url
+        }
+        qry = ServiceOperationQuery(context.web, "UnshareObject", None, payload, None, result)
+        qry.static = True
+        context.add_query(qry)
+        return result
+
+    def get_file_by_id(self, unique_id):
+        """Returns the file object with the specified GUID.
+
+        :param str unique_id: A GUID that identifies the file object.
+        """
+        return_file = File(self.context)
+        qry = ServiceOperationQuery(self.context.web, "GetFileById", [unique_id], None, None, return_file)
+        self.context.add_query(qry)
+        return return_file
+
+    def get_list_item(self, str_url):
+        """
+        Returns the list item that is associated with the specified server-relative URL.
+
+        :param str str_url: A string that contains the server-relative URL,
+        for example, "/sites/MySite/Shared Documents/MyDocument.docx".
+        :return: ListItem
+        """
+        return_item = ListItem(self.context, ResourcePathServiceOperation("GetListItem", [str_url], self.resource_path))
+        return return_item
+
+    def get_catalog(self, type_catalog):
+        """Gets the list template gallery, site template gallery, or Web Part gallery for the Web site.
+
+        :param int type_catalog: The type of the gallery.
+        """
+        return List(self.context, ResourcePathServiceOperation("getCatalog", [type_catalog], self.resource_path))
+
     @property
     def webs(self):
         """Get child webs"""
         if self.is_property_available('Webs'):
             return self.properties['Webs']
         else:
-            from office365.sharepoint.webs.webCollection import WebCollection
+            from office365.sharepoint.webs.web_collection import WebCollection
             parent_web_url = None
             if self.is_property_available('Url'):
                 parent_web_url = self.properties['Url']
@@ -386,19 +556,17 @@ class Web(SecurableObject):
 
     @property
     def url(self):
-        """Gets the absolute URL for the website."""
-        if self.is_property_available('Url'):
-            return self.properties['Url']
-        else:
-            return None
+        """Gets the absolute URL for the website.
+        :rtype: str or None
+        """
+        return self.properties.get('Url', None)
 
     @property
     def web_template(self):
-        """Gets the name of the site definition or site template that was used to create the site."""
-        if self.is_property_available('WebTemplate'):
-            return self.properties['WebTemplate']
-        else:
-            return None
+        """Gets the name of the site definition or site template that was used to create the site.
+        :rtype: str or None
+        """
+        return self.properties.get('WebTemplate', None)
 
     @property
     def regional_settings(self):
@@ -408,15 +576,23 @@ class Web(SecurableObject):
         else:
             return RegionalSettings(self.context, ResourcePath("RegionalSettings", self.resource_path))
 
+    @property
+    def recycleBin(self):
+        """Get recycle bin"""
+        return self.properties.get('RecycleBin',
+                                   RecycleBinItemCollection(self.context,
+                                                            ResourcePath("RecycleBin", self.resource_path)))
+
     def set_property(self, name, value, persist_changes=True):
         super(Web, self).set_property(name, value, persist_changes)
         # fallback: create a new resource path
         if name == "Url":
             self._web_url = value
+        return self
 
     @property
     def resource_url(self):
         url = super(Web, self).resource_url
         if self._web_url is not None:
-            url = url.replace(self.context.service_root_url, self._web_url + '/_api/')
+            url = url.replace(self.context.service_root_url(), self._web_url + '/_api/')
         return url
